<?php

/* Crer Framework - Sanitize
-------------------------------------------------------------- */

/* Text */
add_filter( 'creer_sanitize_text', 'sanitize_text_field' );

/* Textarea */
function creer_sanitize_textarea($input) {
	global $allowedposttags;
	$output = wp_kses( $input, $allowedposttags);
	return $output;
}

add_filter( 'creer_sanitize_textarea', 'creer_sanitize_textarea' );

/* Select */
add_filter( 'creer_sanitize_select', 'creer_sanitize_enum', 10, 2);

/* Radio */
add_filter( 'creer_sanitize_radio', 'creer_sanitize_enum', 10, 2);

/* Images */
add_filter( 'creer_sanitize_images', 'creer_sanitize_enum', 10, 2);

/* Checkbox */
function creer_sanitize_checkbox( $input ) {
	if ( $input ) {
		$output = '1';
	} else {
		$output = false;
	}
	return $output;
}
add_filter( 'creer_sanitize_checkbox', 'creer_sanitize_checkbox' );

/* Multicheck */
function creer_sanitize_multicheck( $input, $option ) {
	$output = '';
	if ( is_array( $input ) ) {
		foreach( $option['options'] as $key => $value ) {
			$output[$key] = "0";
		}
		foreach( $input as $key => $value ) {
			if ( array_key_exists( $key, $option['options'] ) && $value ) {
				$output[$key] = "1";
			}
		}
	}
	return $output;
}
add_filter( 'creer_sanitize_multicheck', 'creer_sanitize_multicheck', 10, 2 );

/* Color Picker */
add_filter( 'creer_sanitize_color', 'creer_sanitize_hex' );

/* Uploader */
function creer_sanitize_upload( $input ) {
	$output = '';
	$filetype = wp_check_filetype($input);
	if ( $filetype["ext"] ) {
		$output = $input;
	}
	return $output;
}
add_filter( 'creer_sanitize_upload', 'creer_sanitize_upload' );

/* Editor */
function creer_sanitize_editor($input) {
	if ( current_user_can( 'unfiltered_html' ) ) {
		$output = $input;
	}
	else {
		global $allowedtags;
		$output = wpautop(wp_kses( $input, $allowedtags));
	}
	return $output;
}
add_filter( 'creer_sanitize_editor', 'creer_sanitize_editor' );

/* Allowed Tags */
function creer_sanitize_allowedtags($input) {
	global $allowedtags;
	$output = wpautop(wp_kses( $input, $allowedtags));
	return $output;
}

/* Allowed Post Tags */
function creer_sanitize_allowedposttags($input) {
	global $allowedposttags;
	$output = wpautop(wp_kses( $input, $allowedposttags));
	return $output;
}

add_filter( 'creer_sanitize_info', 'creer_sanitize_allowedposttags' );


/* Check that the key value sent is valid */
function creer_sanitize_enum( $input, $option ) {
	$output = '';
	if ( array_key_exists( $input, $option['options'] ) ) {
		$output = $input;
	}
	return $output;
}

/* Background */
function creer_sanitize_background( $input ) {
	$output = wp_parse_args( $input, array(
		'color' => '',
		'image'  => '',
		'repeat'  => 'repeat',
		'position' => 'top center',
		'attachment' => 'scroll'
	) );

	$output['color'] = apply_filters( 'creer_sanitize_hex', $input['color'] );
	$output['image'] = apply_filters( 'creer_sanitize_upload', $input['image'] );
	$output['repeat'] = apply_filters( 'creer_background_repeat', $input['repeat'] );
	$output['position'] = apply_filters( 'creer_background_position', $input['position'] );
	$output['attachment'] = apply_filters( 'creer_background_attachment', $input['attachment'] );

	return $output;
}
add_filter( 'creer_sanitize_background', 'creer_sanitize_background' );

function creer_sanitize_background_repeat( $value ) {
	$recognized = creer_recognized_background_repeat();
	if ( array_key_exists( $value, $recognized ) ) {
		return $value;
	}
	return apply_filters( 'creer_default_background_repeat', current( $recognized ) );
}
add_filter( 'creer_background_repeat', 'creer_sanitize_background_repeat' );

function creer_sanitize_background_position( $value ) {
	$recognized = creer_recognized_background_position();
	if ( array_key_exists( $value, $recognized ) ) {
		return $value;
	}
	return apply_filters( 'creer_default_background_position', current( $recognized ) );
}
add_filter( 'creer_background_position', 'creer_sanitize_background_position' );

function creer_sanitize_background_attachment( $value ) {
	$recognized = creer_recognized_background_attachment();
	if ( array_key_exists( $value, $recognized ) ) {
		return $value;
	}
	return apply_filters( 'creer_default_background_attachment', current( $recognized ) );
}
add_filter( 'creer_background_attachment', 'creer_sanitize_background_attachment' );


/* Typography */

function creer_sanitize_typography( $input, $option ) {

	$output = wp_parse_args( $input, array(
		'size'  => '',
		'face'  => '',
		'style' => '',
		'color' => ''
	) );

	if ( isset( $option['options']['faces'] ) && isset( $input['face'] ) ) {
		if ( !( array_key_exists( $input['face'], $option['options']['faces'] ) ) ) {
			$output['face'] = '';
		}
	}
	else {
		$output['face']  = apply_filters( 'creer_font_face', $output['face'] );
	}

	$output['size']  = apply_filters( 'creer_font_size', $output['size'] );
	$output['style'] = apply_filters( 'creer_font_style', $output['style'] );
	$output['color'] = apply_filters( 'creer_sanitize_color', $output['color'] );
	return $output;
}
add_filter( 'creer_sanitize_typography', 'creer_sanitize_typography', 10, 2 );

function creer_sanitize_font_size( $value ) {
	$recognized = creer_recognized_font_sizes();
	$value_check = preg_replace('/px/','', $value);
	if ( in_array( (int) $value_check, $recognized ) ) {
		return $value;
	}
	return apply_filters( 'creer_default_font_size', $recognized );
}
add_filter( 'creer_font_size', 'creer_sanitize_font_size' );


function creer_sanitize_font_style( $value ) {
	$recognized = creer_recognized_font_styles();
	if ( array_key_exists( $value, $recognized ) ) {
		return $value;
	}
	return apply_filters( 'creer_default_font_style', current( $recognized ) );
}
add_filter( 'creer_font_style', 'creer_sanitize_font_style' );


function creer_sanitize_font_face( $value ) {
	$recognized = creer_recognized_font_faces();
	if ( array_key_exists( $value, $recognized ) ) {
		return $value;
	}
	return apply_filters( 'creer_default_font_face', current( $recognized ) );
}
add_filter( 'creer_font_face', 'creer_sanitize_font_face' );

function creer_recognized_background_repeat() {
	$default = array(
		'no-repeat' => __('No Repeat', 'creerthemes'),
		'repeat-x'  => __('Repeat Horizontally', 'creerthemes'),
		'repeat-y'  => __('Repeat Vertically', 'creerthemes'),
		'repeat'    => __('Repeat All', 'creerthemes'),
		);
	return apply_filters( 'creer_recognized_background_repeat', $default );
}

function creer_recognized_background_position() {
	$default = array(
		'top left'      => __('Top Left', 'creerthemes'),
		'top center'    => __('Top Center', 'creerthemes'),
		'top right'     => __('Top Right', 'creerthemes'),
		'center left'   => __('Middle Left', 'creerthemes'),
		'center center' => __('Middle Center', 'creerthemes'),
		'center right'  => __('Middle Right', 'creerthemes'),
		'bottom left'   => __('Bottom Left', 'creerthemes'),
		'bottom center' => __('Bottom Center', 'creerthemes'),
		'bottom right'  => __('Bottom Right', 'creerthemes')
		);
	return apply_filters( 'creer_recognized_background_position', $default );
}

function creer_recognized_background_attachment() {
	$default = array(
		'scroll' => __('Scroll Normally', 'creerthemes'),
		'fixed'  => __('Fixed in Place', 'creerthemes')
		);
	return apply_filters( 'creer_recognized_background_attachment', $default );
}

function creer_sanitize_hex( $hex, $default = '' ) {
	if ( creer_validate_hex( $hex ) ) {
		return $hex;
	}
	return $default;
}

function creer_recognized_font_sizes() {
	$sizes = range( 9, 71 );
	$sizes = apply_filters( 'creer_recognized_font_sizes', $sizes );
	$sizes = array_map( 'absint', $sizes );
	return $sizes;
}

function creer_recognized_font_faces() {
	$default = array(
		'arial'     => 'Arial',
		'verdana'   => 'Verdana, Geneva',
		'trebuchet' => 'Trebuchet',
		'georgia'   => 'Georgia',
		'times'     => 'Times New Roman',
		'tahoma'    => 'Tahoma, Geneva',
		'palatino'  => 'Palatino',
		'helvetica' => 'Helvetica*'
		);
	return apply_filters( 'creer_recognized_font_faces', $default );
}

function creer_recognized_font_styles() {
	$default = array(
		'normal'      => __('Normal', 'creerthemes'),
		'italic'      => __('Italic', 'creerthemes'),
		'bold'        => __('Bold', 'creerthemes'),
		'bold italic' => __('Bold Italic', 'creerthemes')
		);
	return apply_filters( 'creer_recognized_font_styles', $default );
}

function creer_validate_hex( $hex ) {
	$hex = trim( $hex );
	/* Strip recognized prefixes. */
	if ( 0 === strpos( $hex, '#' ) ) {
		$hex = substr( $hex, 1 );
	}
	elseif ( 0 === strpos( $hex, '%23' ) ) {
		$hex = substr( $hex, 3 );
	}
	/* Regex match. */
	if ( 0 === preg_match( '/^[0-9a-fA-F]{6}$/', $hex ) ) {
		return false;
	}
	else {
		return true;
	}
}