<?php
/*
Description: Crer Framework
Author: Crer
Author URI: http://www.creerthemes.com
License: GPLv2
Version: 1.0
*/

add_action('init', 'creerframework_rolescheck' );

function creerframework_rolescheck () {
	if ( current_user_can( 'edit_theme_options' ) ) {
		// If the user can edit theme options, let the fun begin!
		add_action( 'admin_menu', 'creerframework_add_page');
		add_action( 'admin_init', 'creerframework_init' );
		add_action( 'admin_init', 'creerframework_mlu_init' );
		add_action( 'wp_before_admin_bar_render', 'creerframework_adminbar' );
	}
}

/* Loads the file for option sanitization */

add_action('init', 'creerframework_load_sanitization' );

function creerframework_load_sanitization() {
	require_once dirname( __FILE__ ) . '/creer-framework-sanitize.php';
}

function creerframework_init() {

	// Include the required files
	require_once dirname( __FILE__ ) . '/creer-framework-interface.php';
	require_once dirname( __FILE__ ) . '/creer-framework-medialibrary-uploader.php';
	
	// Loads the options array from the theme
	if ( $optionsfile = locate_template( array('/includes/theme-options.php') ) ) {
		require_once($optionsfile);
	}
	else if (file_exists( dirname( __FILE__ ) . '/includes/theme-options.php' ) ) {
		require_once dirname( __FILE__ ) . '/includes/theme-options.php';
	}
	
	$creerframework_settings = get_option('creerframework' );
	
	// Updates the unique option id in the database if it has changed
	creerframework_option_name();
	
	// Gets the unique id, returning a default if it isn't defined
	if ( isset($creerframework_settings['id']) ) {
		$option_name = $creerframework_settings['id'];
	}
	else {
		$option_name = 'creerframework';
	}
	
	// If the option has no saved data, load the defaults
	if ( ! get_option($option_name) ) {
		creerframework_setdefaults();
	}
	
	// Registers the settings fields and callback
	register_setting( 'creerframework', $option_name, 'creerframework_validate' );
	
	// Change the capability required to save the 'creerframework' options group.
	add_filter( 'option_page_capability_creerframework', 'creerframework_page_capability' );
}

function creerframework_page_capability( $capability ) {
	return 'edit_theme_options';
}

function creerframework_setdefaults() {
	
	$creerframework_settings = get_option('creerframework');

	// Gets the unique option id
	$option_name = $creerframework_settings['id'];

	if ( isset($creerframework_settings['knownoptions']) ) {
		$knownoptions =  $creerframework_settings['knownoptions'];
		if ( !in_array($option_name, $knownoptions) ) {
			array_push( $knownoptions, $option_name );
			$creerframework_settings['knownoptions'] = $knownoptions;
			update_option('creerframework', $creerframework_settings);
		}
	} else {
		$newoptionname = array($option_name);
		$creerframework_settings['knownoptions'] = $newoptionname;
		update_option('creerframework', $creerframework_settings);
	}
	
	// Gets the default options data from the array in options.php
	$options = creerframework_options();
	
	// If the options haven't been added to the database yet, they are added now
	$values = creer_get_default_values();
	
	if ( isset($values) ) {
		add_option( $option_name, $values ); // Add option with default settings
	}
}

/* Add a subpage called "Theme Options" to the appearance menu. */
if ( !function_exists( 'creerframework_add_page' ) ) {

	function creerframework_add_page() {
		$icon = CREER_FRAMEWORK_DIRECTORY .'/images/favicon.png';
		$creer_page = add_object_page(__('Theme Options', 'creerthemes'), __('Theme Options', 'creerthemes'), 'edit_theme_options', 'creer-framework','creerframework_page', $icon);
	
		// Load the required CSS and javscript
		add_action('admin_enqueue_scripts', 'creerframework_load_scripts');
		add_action( 'admin_print_styles-' . $creer_page, 'creerframework_load_styles' );
	}
	
}

/* Loads the CSS */
function creerframework_load_styles() {
	wp_enqueue_style('creerframework', CREER_FRAMEWORK_DIRECTORY . 'css/creerframework.css');
	if ( !wp_style_is( 'wp-color-picker','registered' ) ) {
		wp_register_style('wp-color-picker', CREER_FRAMEWORK_DIRECTORY . 'css/color-picker.min.css');
	}
	wp_enqueue_style( 'wp-color-picker' );
}

/* Loads the javascript */
function creerframework_load_scripts($hook) {

	if ( 'toplevel_page_creer-framework' != $hook )
        return;

	// Enqueue colorpicker scripts for versions below 3.5
	// for compatibility
	
	if ( !wp_script_is( 'wp-color-picker', 'registered' ) ) {
		wp_register_script( 'iris', CREER_FRAMEWORK_DIRECTORY . 'js/iris.min.js', array( 'jquery-ui-draggable', 'jquery-ui-slider', 'jquery-touch-punch' ), false, 1 );
		wp_register_script( 'wp-color-picker', CREER_FRAMEWORK_DIRECTORY . 'js/color-picker.min.js', array( 'jquery', 'iris' ) );
		$colorpicker_l10n = array(
			'clear' => __( 'Clear','creerthemes' ),
			'defaultString' => __( 'Default','creerthemes' ),
			'pick' => __( 'Select Color','creerthemes' )
		);
		wp_localize_script( 'wp-color-picker', 'wpColorPickerL10n', $colorpicker_l10n );
	}
	
	// Enqueue custom option panel JS
	wp_enqueue_script( 'options-custom', CREER_FRAMEWORK_DIRECTORY . 'js/creer-custom.js', array( 'jquery','wp-color-picker' ) );

	// Inline scripts from options-interface.php
	add_action( 'admin_head', 'creer_admin_head' );
}

function creer_admin_head() {
	// Hook to add custom scripts
	do_action( 'creerframework_custom_scripts' );
}

if ( !function_exists( 'creerframework_page' ) ) :
function creerframework_page() {
	settings_errors(); ?>

	<div id="creerframework-wrap" class="wrap">
    <?php screen_icon( 'themes' ); ?>
    <h2 class="nav-tab-wrapper">
        <?php echo creerframework_tabs(); ?>
    </h2>

    <div id="creerframework-metabox" class="metabox-holder">
	    <div id="creerframework" class="postbox">
			<form action="options.php" method="post">
			<?php settings_fields('creerframework'); ?>
			<?php creerframework_fields(); /* Settings */ ?>
			<div id="creerframework-submit">
				<input type="submit" class="button-primary" name="update" value="<?php esc_attr_e( 'Save Options', 'creerthemes' ); ?>" />
				<input type="submit" class="reset-button button-secondary" name="reset" value="<?php esc_attr_e( 'Restore Defaults', 'creerthemes' ); ?>" onclick="return confirm( '<?php print esc_js( __( 'Click OK to reset. Any theme settings will be lost!', 'creerthemes' ) ); ?>' );" />
				<div class="clear"></div>
			</div>
			</form>
		</div> <!-- / #container -->
	</div>
	<?php do_action('creerframework_after'); ?>
	</div> <!-- / .wrap -->
	
<?php
}
endif;

function creerframework_validate( $input ) {

	if ( isset( $_POST['reset'] ) ) {
		add_settings_error( 'creer-framework', 'restore_defaults', __( 'Default options restored.', 'creerthemes' ), 'updated fade' );
		return creer_get_default_values();
	}
	 
	$clean = array();
	$options = creerframework_options();
	foreach ( $options as $option ) {

		if ( ! isset( $option['id'] ) ) {
			continue;
		}

		if ( ! isset( $option['type'] ) ) {
			continue;
		}

		$id = preg_replace( '/[^a-zA-Z0-9._\-]/', '', strtolower( $option['id'] ) );

		// Set checkbox to false if it wasn't sent in the $_POST
		if ( 'checkbox' == $option['type'] && ! isset( $input[$id] ) ) {
			$input[$id] = false;
		}

		// Set each item in the multicheck to false if it wasn't sent in the $_POST
		if ( 'multicheck' == $option['type'] && ! isset( $input[$id] ) ) {
			foreach ( $option['options'] as $key => $value ) {
				$input[$id][$key] = false;
			}
		}

		// For a value to be submitted to database it must pass through a sanitization filter
		if ( has_filter( 'creer_sanitize_' . $option['type'] ) ) {
			$clean[$id] = apply_filters( 'creer_sanitize_' . $option['type'], $input[$id], $option );
		}
	}
	
	// Hook to run after validation
	do_action( 'creerframework_after_validate', $clean );
	
	return $clean;
}

function creerframework_save_options_notice() {
	add_settings_error( 'creer-framework', 'save_options', __( 'Options saved.', 'creerthemes' ), 'updated fade' );
}

add_action( 'creerframework_after_validate', 'creerframework_save_options_notice' );
 
function creer_get_default_values() {
	$output = array();
	$config = creerframework_options();
	foreach ( (array) $config as $option ) {
		if ( ! isset( $option['id'] ) ) {
			continue;
		}
		if ( ! isset( $option['std'] ) ) {
			continue;
		}
		if ( ! isset( $option['type'] ) ) {
			continue;
		}
		if ( has_filter( 'creer_sanitize_' . $option['type'] ) ) {
			$output[$option['id']] = apply_filters( 'creer_sanitize_' . $option['type'], $option['std'], $option );
		}
	}
	return $output;
}

function creerframework_adminbar() {

	global $wp_admin_bar;

	$wp_admin_bar->add_menu( array(
			'parent' => 'toplevel',
			'id' => 'creer_theme_options',
			'title' => __( 'Theme Options', 'creerthemes' ),
			'href' => admin_url( 'themes.php?page=creer-framework' )
		));
}

if ( ! function_exists( 'creer_get_option' ) ) {

	function creer_get_option( $name, $default = false ) {
		$config = get_option( 'creerframework' );

		if ( ! isset( $config['id'] ) ) {
			return $default;
		}

		$options = get_option( $config['id'] );

		if ( isset( $options[$name] ) ) {
			return $options[$name];
		}

		return $default;
	}
}