<?php

/* Main Theme Function
--------------------------------------------------------------

This is where you can drop your custom functions or just edit things
like thumbnail sizes, header images, sidebars, comments, ect.
*/

if ( ! isset( $content_width ) ) $content_width = 1140;

/* Include Files
-------------------------------------------------------------- */

require_once('includes/theme-functions.php'); 						// if you remove this, the theme will break
require_once('includes/theme-typography.php'); 						// calls custom fonts
require_once('includes/theme-widgets.php'); 						// calls custom widgets
require_once('framework/shortcodes/creer_shortcodes.php'); 			// call shortcodes
require_once('includes/meta/creer_meta.php');						// calls meta boxes
require_once('includes/meta/creer_meta_config.php');				// calls specific post meta boxes

if ( !function_exists( 'creer_framework_init' ) ) {
	define( 'CREER_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/framework/' );
	require_once dirname( __FILE__ ) . '/framework/creer-framework.php';
}

require_once('lang/translation.php'); //


/* Thumbnail Sizes
-------------------------------------------------------------- */

add_image_size( 'creer-thumb', 310, 232, true );


/* Sidebars & Widgetized Areas
-------------------------------------------------------------- */

function creer_register_sidebars() {
    register_sidebar(array(
    	'id' => 'sidebar-main',
    	'name' => 'Main Sidebar',
    	'description' => 'Main widget area.',
    	'before_widget' => '<div id="%1$s" class="widget %2$s">',
    	'after_widget' => '</div>',
    	'before_title' => '<h4 class="widgettitle">',
    	'after_title' => '</h4>',
    ));

    register_sidebar(array(
    	'id' => 'sidebar-post',
    	'name' => 'Post Sidebar',
    	'description' => 'Widget area for posts & archives.',
    	'before_widget' => '<div id="%1$s" class="widget %2$s">',
    	'after_widget' => '</div>',
    	'before_title' => '<h4 class="widgettitle">',
    	'after_title' => '</h4>',
    ));

    register_sidebar(array(
    	'id' => 'sidebar-page',
    	'name' => 'Page Sidebar',
    	'description' => 'Widget area for pages.',
    	'before_widget' => '<div id="%1$s" class="widget %2$s">',
    	'after_widget' => '</div>',
    	'before_title' => '<h4 class="widgettitle">',
    	'after_title' => '</h4>',
    ));
            
    register_sidebar(array(
    	'id' => 'footer1',
    	'name' => 'Footer 1',
    	'description' => 'First footer widget area.',
    	'before_widget' => '<div id="%1$s" class="widget %2$s">',
    	'after_widget' => '</div>',
    	'before_title' => '<h4 class="widgettitle">',
    	'after_title' => '</h4>',
    ));

    register_sidebar(array(
    	'id' => 'footer2',
    	'name' => 'Footer 2',
    	'description' => 'Second footer widget area',
    	'before_widget' => '<div id="%1$s" class="widget %2$s">',
    	'after_widget' => '</div>',
    	'before_title' => '<h4 class="widgettitle">',
    	'after_title' => '</h4>',
    ));

    register_sidebar(array(
    	'id' => 'footer3',
    	'name' => 'Footer 3',
    	'description' => 'Third footer widget area.',
    	'before_widget' => '<div id="%1$s" class="widget %2$s">',
    	'after_widget' => '</div>',
    	'before_title' => '<h4 class="widgettitle">',
    	'after_title' => '</h4>',
    ));
    
} // don't remove this bracket!


/* Comments
-------------------------------------------------------------- */		

function creer_comments($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>
	<li <?php comment_class(); ?>>
		<article id="comment-<?php comment_ID(); ?>" class="clearfix">
			<header class="comment-author vcard">
			    <?php 
			    /*
			        this is the new responsive optimized comment image. It used the new HTML5 data-attribute to display comment gravatars on larger screens only. What this means is that on larger posts, mobile sites don't have a ton of requests for comment images. This makes load time incredibly fast! If you'd like to change it back, just replace it with the regular wordpress gravatar call:
			        echo get_avatar($comment,$size='32',$default='<path_to_url>' );
			    */ 
			    ?>
			    <!-- custom gravatar call -->
			    <?php
			    	$bgauthemail = get_comment_author_email();
			    ?>
			    <img data-gravatar="http://www.gravatar.com/avatar/<?php echo md5($bgauthemail); ?>?s=120" class="load-gravatar avatar avatar-60 photo" height="60" width="60" src="<?php echo get_template_directory_uri(); ?>/includes/images/nothing.gif" />
				<?php printf(__('<cite class="fn">%s</cite>'), get_comment_author_link()) ?>
				<time datetime="<?php echo comment_time('Y-m-j'); ?>"><a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>"><?php echo human_time_diff( get_comment_time('U'), current_time('timestamp') ) . ' ago'; ?> </a></time>
				<?php edit_comment_link(__('(Edit)', 'creerthemes'),'  ','') ?>
			</header>
			<?php if ($comment->comment_approved == '0') : ?>
       			<div class="alert info">
          			<p><?php _e('Your comment is awaiting moderation.', 'creerthemes') ?></p>
          		</div>
			<?php endif; ?>
			<section class="comment_content clearfix">
				<?php comment_text() ?>
			</section>
			<?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
		</article>
<?php
} // don't remove this bracket!


/* Search Form
-------------------------------------------------------------- */

function creer_wpsearch($form) {
    $form = '<form role="search" method="get" id="searchform" action="' . home_url( '/' ) . '" >
    <input type="text" value="' . get_search_query() . '" name="s" id="s" />
    <input type="submit" id="searchsubmit" value="'. esc_attr__('Search') .'" />
    </form>';
    return $form;
} // don't remove this bracket!


/* Custom Login Page
-------------------------------------------------------------- */

function creer_login_css() {
	echo '<link rel="stylesheet" href="' . get_stylesheet_directory_uri() . '/includes/css/login.css">';
}

function creer_login_url() {  return home_url(); }

function creer_login_title() { return get_option('blogname'); }

add_action('login_head', 'creer_login_css');
add_filter('login_headerurl', 'creer_login_url');
add_filter('login_headertitle', 'creer_login_title');


/* Custom Functions
-------------------------------------------------------------- */
	
	//Add your custom functions below before the closing

?>