<?php

/* Crer Meta Box Options
-------------------------------------------------------------- */

class creer_Meta_Box {

	protected $_meta_box;
	protected $_fields;

	function __construct($meta_box) {
		if (!is_admin()) return;

		$this->_meta_box = $meta_box;
		$this->_fields = & $this->_meta_box['fields'];
		$this->add_missed_values();

		add_action('admin_menu', array(&$this, 'add'));
		add_action('save_post', array(&$this, 'save'));

		$this->check_field_upload();
		$this->check_field_color();
		$this->check_field_date();
		$this->check_field_time();
	}

	function check_field_upload() {
		if ($this->has_field('image') || $this->has_field('file')) {
			add_action('post_edit_form_tag', array(&$this, 'add_enctype'));

			wp_enqueue_script('jquery-ui-core');
			wp_enqueue_script('jquery-ui-sortable');
			add_action('admin_head-post.php', array(&$this, 'add_script_upload'));
			add_action('admin_head-post-new.php', array(&$this, 'add_script_upload'));
			
			add_action('delete_post', array(&$this, 'delete_attachments'));
			add_action('wp_ajax_creer_delete_file', array(&$this, 'delete_file'));
			add_action('wp_ajax_creer_reorder_images', array(&$this, 'reorder_images'));
		}
	}

	function add_enctype() {
		echo ' enctype="multipart/form-data"';
	}

	function add_script_upload() {
		global $post;
		echo '
		<style type="text/css">
		.creer-images li {margin: 0 10px 10px 0; float: left; width: 150px; height: 100px; text-align: center; border: 3px solid #ccc; cursor: move; position: relative}
		.creer-images img {width: 150px; height: 100px}
		.creer-images a {position: absolute; bottom: 0; right: 0; color: #fff; background: #000; font-weight: bold; padding: 5px}
		</style>
		';
		
		echo '
		<script type="text/javascript">
		jQuery(document).ready(function($) {
		';
		
		echo '
			// add more file
			$(".creer-add-file").click(function(){
				var $first = $(this).parent().find(".file-input:first");
				$first.clone().insertAfter($first).show();
				return false;
			});
		';
		
		echo '
			// delete file
			$(".creer-delete-file").click(function(){
				var $parent = $(this).parent(),
					data = $(this).attr("rel");
				$.post(ajaxurl, {action: \'creer_delete_file\', data: data}, function(response){
					if (response == "0") {
						alert("' . __('File has been successfully deleted.', 'creerthemes', 'creerthemes') . '");
						$parent.remove();
					}
					if (response == "1") {
						alert("' . __("You don't have permission to delete this file.", 'creerthemes') . '");
					}
				});
				return false;
			});
		';
		
		foreach ($this->_fields as $field) {
			if ('image' != $field['type']) continue;
			
			$id = $field['id'];
			$nonce_delete = wp_create_nonce('creer_ajax_delete_file');
			echo "
			// thickbox upload
			$('#creer_upload_$id').click(function(){
				backup = window.send_to_editor;
				window.send_to_editor = function(html) {
					var el = $(html).is('a') ? $('img', html) : $(html),
						img_url = el.attr('src'),
						img_id = el.attr('class');
					
					img_id = img_id.slice((img_id.search(/wp-image-/) + 9));
					
					html = '<li id=\"item_' + img_id + '\">';
					html += '<img src=\"' + img_url + '\" />';
					html += '<a title=\"" . __('Delete this image', 'creerthemes') . "\" class=\"creer-delete-file\" href=\"#\" rel=\"{$post->ID}!$id!' + img_id + '!$nonce_delete\">" . __('Delete', 'creerthemes') . "</a>';
					html += '<input type=\"hidden\" name=\"{$id}[]\" value=\"' + img_id + '\" />';
					html += '</li>';
					
					$('#creer-images-$id').append($(html));
					
					tb_remove();
					window.send_to_editor = backup;
				}
				tb_show('', 'media-upload.php?post_id={$post->ID}; ?>&type=image&TB_iframe=true');
				
				return false;
			});
			";
			
			echo "
			// sort
			$('#creer-images-$id').sortable({
				placeholder: 'ui-state-highlight',
				update: function (){
					var order = $('#creer-images-$id').sortable('serialize'),
						data = order + '!' + $('#creer-data-$id').val();
					$.post(ajaxurl, {action: 'creer_reorder_images', data: data}, function(response){
						if (response == '0') {
							alert('" . __('Order saved.', 'creerthemes') . "');
						}
						if (response == '1') {
							alert(\"" . __("You don't have permission to reorder images.", 'creerthemes') . "\");
						}
					});
				}
			});
			";
		}
		
		echo '});
		</script>
		';
	}

	function delete_attachments($post_id) {
		$attachments = get_posts(array(
			'numberposts' => -1,
			'post_type' => 'attachment',
			'post_parent' => $post_id
		));
		if (!empty($attachments)) {
			foreach ($attachments as $att) {
				wp_delete_attachment($att->ID);
			}
		}
	}

	function delete_file() {
		if (!isset($_POST['data'])) die();

		list($post_id, $key, $attach_id, $nonce) = explode('!', $_POST['data']);

		if (!wp_verify_nonce($nonce, 'creer_ajax_delete_file')) {
			die('1');
		}

		wp_delete_attachment($attach_id);
		delete_post_meta($post_id, $key, $attach_id);

		die('0');
	}
	
	function reorder_images() {
		if (!isset($_POST['data'])) die();

		list($order, $post_id, $key, $nonce) = explode('!',$_POST['data']);

		if (!wp_verify_nonce($nonce, 'creer_ajax_sort_file')) {
			die('1');
		}

		parse_str($order, $items);
		$items = $items['item'];
		$order = 0;
		$meta = array();
		foreach ($items as $item) {
			wp_update_post(array(
				'ID' => $item,
				'post_parent' => $post_id,
				'menu_order' => $order
			));
			$order++;
			$meta[] = $item;
		}
		delete_post_meta($post_id, $key);
		foreach ($meta as $value) {
			add_post_meta($post_id, $key, $value);
		}

		die('0');
	}

	function check_field_color() {
		if ($this->has_field('color') && $this->is_edit_page()) {
			wp_enqueue_style('farbtastic');
			wp_enqueue_script('farbtastic');
			add_action('admin_head', array(&$this, 'add_script_color'));
		}
	}

	function add_script_color() {
		$ids = array();
		foreach ($this->_fields as $field) {
			if ('color' == $field['type']) {
				$ids[] = $field['id'];
			}
		}
		echo '
		<script type="text/javascript">
		jQuery(document).ready(function($){
		';
		foreach ($ids as $id) {
			echo "
			$('#picker-$id').farbtastic('#$id');
			$('#select-$id').click(function(){
				$('#picker-$id').toggle();
				return false;
			});
			";
		}
		echo '
		});
		</script>
		';
	}

	function check_field_date() {
		if ($this->has_field('date') && $this->is_edit_page()) {
			// add style and script, use proper jQuery UI version
			wp_enqueue_style('creer-jquery-ui-css', 'http://ajax.googleapis.com/ajax/libs/jqueryui/' . $this->get_jqueryui_ver() . '/themes/base/jquery-ui.css');
			wp_enqueue_script('creer-jquery-ui', 'https://ajax.googleapis.com/ajax/libs/jqueryui/' . $this->get_jqueryui_ver() . '/jquery-ui.min.js', array('jquery'));
			add_action('admin_head', array(&$this, 'add_script_date'));
		}
	}

	function add_script_date() {
		$dates = array();
		foreach ($this->_fields as $field) {
			if ('date' == $field['type']) {
				$dates[$field['id']] = $field['format'];
			}
		}
		echo '
		<script type="text/javascript">
		jQuery(document).ready(function($){
		';
		foreach ($dates as $id => $format) {
			echo "$('#$id').datepicker({
				dateFormat: '$format',
				showButtonPanel: true
			});";
		}
		echo '
		});
		</script>
		';
	}

	function check_field_time() {
		if ($this->has_field('time') && $this->is_edit_page()) {
			// add style and script, use proper jQuery UI version
			wp_enqueue_style('creer-jquery-ui-css', 'http://ajax.googleapis.com/ajax/libs/jqueryui/' . $this->get_jqueryui_ver() . '/themes/base/jquery-ui.css');
			wp_enqueue_script('creer-jquery-ui', 'https://ajax.googleapis.com/ajax/libs/jqueryui/' . $this->get_jqueryui_ver() . '/jquery-ui.min.js', array('jquery'));
			wp_enqueue_script('creer-timepicker', 'https://github.com/trentrichardson/jQuery-Timepicker-Addon/raw/master/jquery-ui-timepicker-addon.js', array('creer-jquery-ui'));
			add_action('admin_head', array(&$this, 'add_script_time'));
		}
	}

	function add_script_time() {
		// style
		echo '
		<style type="text/css">
		.ui-timepicker-div {font-size: 0.9em;}
		.ui-timepicker-div .ui-widget-header {margin-bottom: 8px;}
		.ui-timepicker-div dl {text-align: left;}
		.ui-timepicker-div dl dt {height: 25px;}
		.ui-timepicker-div dl dd {margin: -25px 0 10px 65px;}
		.ui-timepicker-div td {font-size: 90%;}
		</style>
		';

		// script
		$times = array();
		foreach ($this->_fields as $field) {
			if ('time' == $field['type']) {
				$times[$field['id']] = $field['format'];
			}
		}
		echo '
		<script type="text/javascript">
		jQuery(document).ready(function($){
		';
		foreach ($times as $id => $format) {
			echo "$('#$id').timepicker({showSecond: true, timeFormat: '$format'})";
		}
		echo '
		});
		</script>
		';
	}

	function add() {
		foreach ($this->_meta_box['pages'] as $page) {
			add_meta_box($this->_meta_box['id'], $this->_meta_box['title'], array(&$this, 'show'), $page, $this->_meta_box['context'], $this->_meta_box['priority']);
		}
	}

	function show() {
		global $post;

		wp_nonce_field(basename(__FILE__), 'creer_meta_box_nonce');
		echo '<table class="form-table">';

		foreach ($this->_fields as $field) {
			$meta = get_post_meta($post->ID, $field['id'], !$field['multiple']);
			$meta = !empty($meta) ? $meta : $field['std'];
			
			$meta = is_array($meta) ? array_map('esc_attr', $meta) : esc_attr($meta);

			echo '<tr>';
			call_user_func(array(&$this, 'show_field_' . $field['type']), $field, $meta);
			echo '</tr>';
		}
		echo '</table>';
	}
	
	/* Meta Box Fields */

	function show_field_begin($field, $meta) {
		echo "<th style='width:20%'><label for='{$field['id']}'><strong>{$field['name']}</strong></label></th><td>";
	}

	function show_field_end($field, $meta) {
		echo "<br />{$field['desc']}</td>";
	}

	function show_field_text($field, $meta) {
		$this->show_field_begin($field, $meta);
		echo "<input type='text' name='{$field['id']}' id='{$field['id']}' value='$meta' size='30' style='{$field['style']}' />";
		$this->show_field_end($field, $meta);
	}

	function show_field_textarea($field, $meta) {
		$this->show_field_begin($field, $meta);
		echo "<textarea name='{$field['id']}' cols='60' rows='7' style='{$field['style']}'>$meta</textarea>";
		$this->show_field_end($field, $meta);
	}

	function show_field_select($field, $meta) {
		if (!is_array($meta)) $meta = (array) $meta;
		$this->show_field_begin($field, $meta);
		echo "<select name='{$field['id']}" . ($field['multiple'] ? "[]' multiple='multiple' style='{$field['style']}'" : "'") . ">";
		foreach ($field['options'] as $key => $value) {
			echo "<option value='$value'" . selected(in_array($value, $meta), true, false) . ">$value</option>";
		}
		echo "</select>";
		$this->show_field_end($field, $meta);
	}

	function show_field_radio($field, $meta) {
		$this->show_field_begin($field, $meta);
		foreach ($field['options'] as $key => $value) {
			echo "<input type='radio' name='{$field['id']}' value='$key'" . checked($meta, $key, false) . " /> $value ";
		}
		$this->show_field_end($field, $meta);
	}

	function show_field_checkbox($field, $meta) {
		$this->show_field_begin($field, $meta);
		echo "<input type='checkbox' name='{$field['id']}'" . checked(!empty($meta), true, false) . " /> {$field['desc']}</td>";
	}

	function show_field_wysiwyg($field, $meta) {
		$this->show_field_begin($field, $meta);
		echo "<textarea name='{$field['id']}' class='theEditor' cols='60' rows='15' style='{$field['style']}'>$meta</textarea>";
		$this->show_field_end($field, $meta);
	}

	function show_field_file($field, $meta) {
		global $post;

		if (!is_array($meta)) $meta = (array) $meta;

		$this->show_field_begin($field, $meta);
		echo "{$field['desc']}<br />";

		if (!empty($meta)) {
			$nonce = wp_create_nonce('creer_ajax_delete_file');
			echo '<div style="margin-bottom: 10px"><strong>' . __('Uploaded files', 'creerthemes') . '</strong></div>';
			echo '<ol>';
			foreach ($meta as $att) {
				if (wp_attachment_is_image($att)) continue;
				echo "<li>" . wp_get_attachment_link($att) . " (<a class='creer-delete-file' href='#' rel='{$post->ID}!{$field['id']}!$att!$nonce'>" . __('Delete', 'creerthemes') . "</a>)</li>";
			}
			echo '</ol>';
		}

		// show form upload
		echo "<div style='clear: both'><strong>" . __('Upload new files', 'creerthemes') . "</strong></div>
			<div class='new-files'>
				<div class='file-input'><input type='file' name='{$field['id']}[]' /></div>
				<a class='creer-add-file' href='#'>" . __('Add more file', 'creerthemes') . "</a>
			</div>
		</td>";
	}

	function show_field_image($field, $meta) {
		global $post;

		if (!is_array($meta)) $meta = (array) $meta;

		$this->show_field_begin($field, $meta);
		echo "{$field['desc']}<br />";
		
		$nonce_delete = wp_create_nonce('creer_ajax_delete_file');
		$nonce_sort = wp_create_nonce('creer_ajax_sort_file');

		echo "<input type='hidden' id='creer-data-{$field['id']}' value='{$post->ID}!{$field['id']}!$nonce_sort' />
			  <ul id='creer-images-{$field['id']}' class='creer-images'>";
		
		foreach ($meta as $att) {
			$src = wp_get_attachment_image_src($att, 'full');
			$src = $src[0];

			echo "<li id='item_{$att}'>
					<img src='$src' />
					<a title='" . __('Delete this image', 'creerthemes') . "' class='creer-delete-file' href='#' rel='{$post->ID}!{$field['id']}!$att!$nonce_delete'>" . __('Delete', 'creerthemes') . "</a>
					<input type='hidden' name='{$field['id']}[]' value='$att' />
				</li>";
		}
		echo '</ul>';
		
		echo "<a href='#' style='float: left; clear: both; margin-top: 10px' id='creer_upload_{$field['id']}' class='creer_upload button'>" . __('Upload new image / Image options', 'creerthemes') . "</a>";
	}

	function show_field_color($field, $meta) {
		if (empty($meta)) $meta = '#';
		$this->show_field_begin($field, $meta);
		echo "<input type='text' name='{$field['id']}' id='{$field['id']}' value='$meta' size='8' style='{$field['style']}' />
			  <a href='#' id='select-{$field['id']}'>" . __('Select a color', 'creerthemes') . "</a>
			  <div style='display:none' id='picker-{$field['id']}'></div>";
		$this->show_field_end($field, $meta);
	}

	function show_field_checkbox_list($field, $meta) {
		if (!is_array($meta)) $meta = (array) $meta;
		$this->show_field_begin($field, $meta);
		$html = array();
		foreach ($field['options'] as $key => $value) {
			$html[] = "<input type='checkbox' name='{$field['id']}[]' value='$key'" . checked(in_array($key, $meta), true, false) . " /> $value";
		}
		echo implode('<br />', $html);
		$this->show_field_end($field, $meta);
	}

	function show_field_date($field, $meta) {
		$this->show_field_text($field, $meta);
	}

	function show_field_time($field, $meta) {
		$this->show_field_text($field, $meta);
	}

	function save($post_id) {
		global $post_type;
		$post_type_object = get_post_type_object($post_type);

		if ((defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
		|| (!isset($_POST['post_ID']) || $post_id != $_POST['post_ID'])
		|| (!in_array($post_type, $this->_meta_box['pages']))
		|| (!check_admin_referer(basename(__FILE__), 'creer_meta_box_nonce'))
		|| (!current_user_can($post_type_object->cap->edit_post, $post_id))) {	
			return $post_id;
		}

		foreach ($this->_fields as $field) {
			$name = $field['id'];
			$type = $field['type'];
			$old = get_post_meta($post_id, $name, !$field['multiple']);
			$new = isset($_POST[$name]) ? $_POST[$name] : ($field['multiple'] ? array() : '');

			if (class_exists('creer_Meta_Box_Validate') && method_exists('creer_Meta_Box_Validate', $field['validate_func'])) {
				$new = call_user_func(array('creer_Meta_Box_Validate', $field['validate_func']), $new);
			}

			$save_func = 'save_field_' . $type;
			if (method_exists($this, $save_func)) {
				call_user_func(array(&$this, 'save_field_' . $type), $post_id, $field, $old, $new);
			} else {
				$this->save_field($post_id, $field, $old, $new);
			}
		}
	}

	function save_field($post_id, $field, $old, $new) {
		$name = $field['id'];

		delete_post_meta($post_id, $name);
		if (empty($new)) return;
		
		if ($field['multiple']) {
			foreach ($new as $add_new) {
				add_post_meta($post_id, $name, $add_new, false);
			}
		} else {
			update_post_meta($post_id, $name, $new);
		}
		
	}

	function save_field_wysiwyg($post_id, $field, $old, $new) {
		$new = wpautop($new);
		$this->save_field($post_id, $field, $old, $new);
	}

	function save_field_file($post_id, $field, $old, $new) {
		$name = $field['id'];
		if (empty($_FILES[$name])) return;

		$this->fix_file_array($_FILES[$name]);

		foreach ($_FILES[$name] as $position => $fileitem) {
			$file = wp_handle_upload($fileitem, array('test_form' => false));

			if (empty($file['file'])) continue;
			$filename = $file['file'];

			$attachment = array(
				'post_mime_type' => $file['type'],
				'guid' => $file['url'],
				'post_parent' => $post_id,
				'post_title' => preg_replace('/\.[^.]+$/', '', basename($filename)),
				'post_content' => ''
			);
			$id = wp_insert_attachment($attachment, $filename, $post_id);
			if (!is_wp_error($id)) {
				wp_update_attachment_metadata($id, wp_generate_attachment_metadata($id, $filename));
				add_post_meta($post_id, $name, $id, false);	// save file's url in meta fields
			}
		}
	}

	function add_missed_values() {
		$this->_meta_box = array_merge(array(
			'context' => 'normal',
			'priority' => 'high',
			'pages' => array('post')
		), $this->_meta_box);

		foreach ($this->_fields as & $field) {
			$multiple = in_array($field['type'], array('checkbox_list', 'file', 'image')) ? true : false;
			$std = $multiple ? array() : '';
			$format = 'date' == $field['type'] ? 'yy-mm-dd' : ('time' == $field['type'] ? 'hh:mm' : '');
			$style = 'width: 97%';
			if ('select' == $field['type']) $style = 'height: auto';
			
			$field = array_merge(array(
				'multiple' => $multiple,
				'std' => $std,
				'desc' => '',
				'format' => $format,
				'style' => $style,
				'validate_func' => ''
			), $field);
		}
	}

	function has_field($type) {
		foreach ($this->_fields as $field) {
			if ($type == $field['type']) return true;
		}
		return false;
	}

	function is_edit_page() {
		global $pagenow;
		if (in_array($pagenow, array('post.php', 'post-new.php'))) return true;
		return false;
	}

	function fix_file_array(&$files) {
		$output = array();
		foreach ($files as $key => $list) {
			foreach ($list as $index => $value) {
				$output[$index][$key] = $value;
			}
		}
		$files = $output;
	}
	
	function get_jqueryui_ver() {
		global $wp_version;
		if (version_compare($wp_version, '3.1', '>=')) {
			return '1.8.10';
		}
		
		return '1.7.3';
	}

}

?>
