<?php

/* Theme Functions
-------------------------------------------------------------- 

NOTE: It is best not to edit this file as it contains most of the core functions.
If you want to add any custom functions, it's best to put them in functions.php

*/

add_action('after_setup_theme','creer_ahoy', 15);

function creer_ahoy() {

    add_action('init', 'creer_head_cleanup');
    add_filter('the_generator', 'creer_rss_version');
    add_filter( 'wp_head', 'creer_remove_wp_widget_recent_comments_style', 1 );
    add_action('wp_head', 'creer_remove_recent_comments_style', 1);
    add_filter('gallery_style', 'creer_gallery_style');

    add_action('wp_enqueue_scripts', 'creer_scripts_and_styles', 999);
    add_filter( 'style_loader_tag', 'creer_ie_conditional', 10, 2 );

    add_action('after_setup_theme','creer_theme_support');
    add_action( 'widgets_init', 'creer_register_sidebars' );
    add_filter( 'get_search_form', 'creer_wpsearch' );

    add_filter('the_content', 'creer_filter_ptags_on_images');
    add_filter('excerpt_more', 'creer_excerpt_more');

}

/* Cleans wp_head */

function creer_head_cleanup() {
	remove_action( 'wp_head', 'rsd_link' );
	remove_action( 'wp_head', 'wlwmanifest_link' );
	remove_action( 'wp_head', 'index_rel_link' );
	remove_action( 'wp_head', 'parent_post_rel_link', 10, 0 );
	remove_action( 'wp_head', 'start_post_rel_link', 10, 0 );
	remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0 );
	remove_action( 'wp_head', 'wp_generator' );
  add_filter( 'style_loader_src', 'creer_remove_wp_ver_css_js', 9999 );
  add_filter( 'script_loader_src', 'creer_remove_wp_ver_css_js', 9999 );

}

function creer_rss_version() { return ''; }

function creer_remove_wp_ver_css_js( $src ) {
    if ( strpos( $src, 'ver=' ) )
        $src = remove_query_arg( 'ver', $src );
    return $src;
}

function creer_remove_wp_widget_recent_comments_style() {
   if ( has_filter('wp_head', 'wp_widget_recent_comments_style') ) {
      remove_filter('wp_head', 'wp_widget_recent_comments_style' );
   }
}

function creer_remove_recent_comments_style() {
  global $wp_widget_factory;
  if (isset($wp_widget_factory->widgets['WP_Widget_Recent_Comments'])) {
    remove_action('wp_head', array($wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style'));
  }
}

function creer_gallery_style($css) {
  return preg_replace("!<style type='text/css'>(.*?)</style>!s", '', $css);
}

/* Scripts & Enqeueing */

function creer_scripts_and_styles() {
  if (!is_admin()) {

    wp_register_script( 'creer-modernizr', get_stylesheet_directory_uri() . '/includes/js/modernizr.custom.min.js', array(), '2.5.3', false );
    wp_register_style( 'creer-stylesheet', get_stylesheet_directory_uri() . '/style.css', array(), '', 'all' );
    wp_register_style( 'creer-icon', get_stylesheet_directory_uri() . '/includes/fonts/font-awesome.css', array(), '', 'all' );
    wp_register_style( 'creer-ie-only', get_stylesheet_directory_uri() . '/includes/css/ie.css', array(), '' );

    if ( is_singular() AND comments_open() AND (get_option('thread_comments') == 1)) {
      wp_enqueue_script( 'comment-reply' );
    }
    
    wp_register_script( 'fitvids-js', get_stylesheet_directory_uri() . '/includes/js/jquery.fitvids.js', array( 'jquery' ), '', true );
    wp_register_script( 'creer-js', get_stylesheet_directory_uri() . '/includes/js/scripts.js', array( 'jquery' ), '', true );
    wp_register_script( 'nav-js', get_stylesheet_directory_uri() . '/includes/js/nav.js', array( 'jquery' ), '', true );
    wp_register_script( 'jplayer-js', get_stylesheet_directory_uri() . '/includes/js/jquery.jplayer.min.js', array( 'jquery' ), '', true );
    wp_register_script('twitterjs', 'http://twitterjs.googlecode.com/svn/trunk/src/twitter.min.js', array('jquery') );

    wp_enqueue_script( 'creer-modernizr' );
    wp_enqueue_style( 'creer-stylesheet' );
    wp_enqueue_style( 'creer-icon' );
    wp_enqueue_style('creer-ie-only');

    wp_enqueue_script( 'jquery' );
    wp_enqueue_script( 'creer-js' );
    wp_enqueue_script( 'nav-js' );
    wp_enqueue_script( 'fitvids-js' );
    wp_enqueue_script( 'flexslider-js' );
    wp_enqueue_script( 'jplayer-js' );
    wp_enqueue_script( 'twitterjs' );
  }
}

function enqueueAdminScripts() {
	wp_enqueue_script('raw_admin_custom', get_template_directory_uri() .'/includes/js/meta.js', array('jquery'), false );
}
add_action('admin_print_scripts-post.php', 'enqueueAdminScripts');
add_action('admin_print_scripts-edit.php', 'enqueueAdminScripts');
add_action('admin_print_scripts-post-new.php', 'enqueueAdminScripts');

function creer_ie_conditional( $tag, $handle ) {
	if ( 'creer-ie-only' == $handle )
		$tag = '<!--[if lt IE 9]>' . "\n" . $tag . '<![endif]-->' . "\n";
	return $tag;
}

function creer_stylesheets_alt_style()   {
	if ( creer_get_option('stylesheet') ) {
		wp_enqueue_style( 'creer_stylesheets_alt_style', creer_get_option('stylesheet'), array(), null );
	}
}
add_action( 'wp_enqueue_scripts', 'creer_stylesheets_alt_style' );

function creer_stylesheets_get_file_list( $directory_path, $filetype, $directory_uri ) {
	$alt_stylesheets = array();
	$alt_stylesheet_files = array();
	if ( is_dir( $directory_path ) ) {
		$alt_stylesheet_files = glob( $directory_path . "*.$filetype");
		foreach ( $alt_stylesheet_files as $file ) {
			$file = str_replace( $directory_path, "", $file);
			$alt_stylesheets[ $directory_uri . $file] = $file;
		}
	}
	return $alt_stylesheets;
}

/* Theme Support */

function creer_theme_support() {

	add_theme_support('post-thumbnails');

	set_post_thumbnail_size(125, 125, true);

	add_theme_support('automatic-feed-links');

	add_theme_support( 'post-formats',
		array(
			'aside',             // title less blurb
			'gallery',           // gallery of images
			'link',              // quick link to other site
			'image',             // an image
			'quote',             // a quick quote
			'status',		 	 // a status post
			'video',             // video
			'audio',             // audio
		)
	);

	add_theme_support( 'menus' );

	register_nav_menus(
		array(
			'main-nav' => __( 'The Main Menu', 'creerthemes' ),   // main nav in header
			'footer-links' => __( 'Footer Links', 'creerthemes' ) // secondary nav in footer
		)
	);
}


/* Menus & Navigation */

function creer_main_nav() {
	// display the wp3 menu if available
    wp_nav_menu(array(
    	'container' => false,                           // remove nav container
    	'container_class' => 'menu clearfix',           // class of container (should you choose to use it)
    	'menu' => 'The Main Menu',                      // nav name
    	'menu_class' => 'nav top-nav clearfix',         // adding custom nav class
    	'theme_location' => 'main-nav',                 // where it's located in the theme
    	'before' => '',                                 // before the menu
        'after' => '',                                  // after the menu
        'link_before' => '',                            // before each link
        'link_after' => '',                             // after each link
        'depth' => 0,                                   // limit the depth of the nav
    	'fallback_cb' => 'creer_main_nav_fallback'      // fallback function
	));
}

function creer_footer_links() {
    wp_nav_menu(array(
    	'container' => '',                              // remove nav container
    	'container_class' => 'footer-links clearfix',   // class of container (should you choose to use it)
    	'menu' => 'Footer Links',                       // nav name
    	'menu_class' => 'nav footer-nav clearfix',      // adding custom nav class
    	'theme_location' => 'footer-links',             // where it's located in the theme
    	'before' => '',                                 // before the menu
        'after' => '',                                  // after the menu
        'link_before' => '',                            // before each link
        'link_after' => '',                             // after each link
        'depth' => 0,                                   // limit the depth of the nav
    	'fallback_cb' => 'creer_footer_links_fallback'  // fallback function
	));
}

function creer_main_nav_fallback() {
	wp_page_menu( array(
		'show_home' => true,
    	'menu_class' => 'nav footer-nav clearfix',      // adding custom nav class
		'include'     => '',
		'exclude'     => '',
		'echo'        => true,
        'link_before' => '',                            // before each link
        'link_after' => ''                             // after each link
	) );
}

function creer_footer_links_fallback() {
}

add_action('admin_init','optionscheck_change_santiziation', 100);
  
function optionscheck_change_santiziation() {
    remove_filter( 'creer_sanitize_textarea', 'creer_sanitize_textarea' );
    add_filter( 'creer_sanitize_textarea', 'custom_sanitize_textarea' );
}
  
function custom_sanitize_textarea($input) {
    global $allowedposttags;
    $custom_allowedtags["embed"] = array(
      "src" => array(),
      "type" => array(),
      "allowfullscreen" => array(),
      "allowscriptaccess" => array(),
      "height" => array(),
          "width" => array()
      );
      $custom_allowedtags["script"] = array();
  
      $custom_allowedtags = array_merge($custom_allowedtags, $allowedposttags);
      $output = wp_kses( $input, $custom_allowedtags);
    return $output;
}

/* Créer Head */
function creer_head() {
		
		echo '<style type="text/css" id="custom-css">';
		
		$customcss = creer_get_option('custom_css');
			echo $customcss;
            		
		$background = creer_get_option('custom_bg');
            if ($background) {
                if ($background['image']) {
                	echo 'body{';
                    echo 'background-color:'.$background['color'].';';
                    echo 'background-image:url(\''.$background['image'].'\');';
                    echo 'background-repeat:'.$background['repeat'].';';
                    echo 'background-position:'.$background['position'].';';
                    echo 'background-attachment:'.$background['attachment'].';';
                    echo '}';
                    	
                } elseif ($background['color']) {
                	echo 'body{';
                    echo 'background-color:'.$background['color'].';';
                    echo '}';
                }	
            } else {
                echo "";
            };
         
        $linkcolor = creer_get_option('link_color');  		
			if ($linkcolor) {
				echo 'a,.creer_page_navi li a,.logo h1 a:hover,.nav a:hover.creer_page_navi li a:focus{color:'.$linkcolor.';}';
				
				echo '::selection,.button,.button:visited,input[type="submit"],a.read-more,.jp-play:hover,.jp-pause:hover,.jp-mute:hover,.jp-unmute:hover,.jp-play-bar,.jp-volume-bar-value,.creer_page_navi li a:hover,.creer_page_navi li a:focus,.creer_page_navi li.bpn-prev-link a:hover,.creer_page_navi li.bpn-next-link a:hover,.creer_page_navi li.bpn-first-page-link a:hover,.creer_page_navi li.bpn-last-page-link a:hover,.creer_page_navi li.bpn-current {background-color:'.$linkcolor.';}';
			}
			
		$hovercolor = creer_get_option('hover_color');  		
			if ($hovercolor) {
				echo 'a:hover,h1 a:hover,.h1 a:hover,h2 a:hover,.h2 a:hover,h3 a:hover,.h3 a:hover,h4 a:hover,.h4 a:hover,h5 a:hover,.h5 a:hover,.creer_page_navi li a:hover,.creer_page_navi li a:focus,.commentlist li.bypostauthor cite.fn a,ul.footer-nav a:hover,.twitter-feed li a:hover,.byline a:hover,.copyright a:hover,ul.footer-nav a:hover,ul.footer-nav li.current-menu-item a:hover,ul.footer-nav li.current-page-item a:hover{color:'.$hovercolor.';}';
			}	
			
	echo '</style>';
}


/* Related Posts */

// Related Posts Function (call using creer_related_posts(); )
function creer_related_posts() {
	echo '<h4>Related Posts</h4><ul id="creer-related-posts">';
	global $post;
	$tags = wp_get_post_tags($post->ID);
	if($tags) {
		foreach($tags as $tag) { $tag_arr .= $tag->slug . ','; }
        $args = array(
        	'tag' => $tag_arr,
        	'numberposts' => 5,
        	'post__not_in' => array($post->ID)
     	);
        $related_posts = get_posts($args);
        if($related_posts) {
        	foreach ($related_posts as $post) : setup_postdata($post); ?>
	           	<li class="related_post"><a class="entry-unrelated" href="<?php the_permalink() ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></li>
	        <?php endforeach; }
	    else { ?>
            <?php echo '<li class="no_related_post">No related posts yet!</li>'; ?>
		<?php }
	}
	wp_reset_query();
	echo '</ul>';
}

/* Page Navi */

function creer_page_navi($before = '', $after = '') {
	global $wpdb, $wp_query;
	$request = $wp_query->request;
	$posts_per_page = intval(get_query_var('posts_per_page'));
	$paged = intval(get_query_var('paged'));
	$numposts = $wp_query->found_posts;
	$max_page = $wp_query->max_num_pages;
	if ( $numposts <= $posts_per_page ) { return; }
	if(empty($paged) || $paged == 0) {
		$paged = 1;
	}
	$pages_to_show = 7;
	$pages_to_show_minus_1 = $pages_to_show-1;
	$half_page_start = floor($pages_to_show_minus_1/2);
	$half_page_end = ceil($pages_to_show_minus_1/2);
	$start_page = $paged - $half_page_start;
	if($start_page <= 0) {
		$start_page = 1;
	}
	$end_page = $paged + $half_page_end;
	if(($end_page - $start_page) != $pages_to_show_minus_1) {
		$end_page = $start_page + $pages_to_show_minus_1;
	}
	if($end_page > $max_page) {
		$start_page = $max_page - $pages_to_show_minus_1;
		$end_page = $max_page;
	}
	if($start_page <= 0) {
		$start_page = 1;
	}
	echo $before.'<nav class="page-navigation"><ol class="creer_page_navi clearfix">'."";
	if ($start_page >= 2 && $pages_to_show < $max_page) {
		$first_page_text = "First";
		echo '<li class="bpn-first-page-link"><a href="'.get_pagenum_link().'" title="'.$first_page_text.'">'.$first_page_text.'</a></li>';
	}
	echo '<li class="bpn-prev-link">';
	previous_posts_link('<i class="icon-angle-left"></i>');
	echo '</li>';
	for($i = $start_page; $i  <= $end_page; $i++) {
		if($i == $paged) {
			echo '<li class="bpn-current">'.$i.'</li>';
		} else {
			echo '<li><a href="'.get_pagenum_link($i).'">'.$i.'</a></li>';
		}
	}
	echo '<li class="bpn-next-link">';
	next_posts_link('<i class="icon-angle-right"></i>');
	echo '</li>';
	if ($end_page < $max_page) {
		$last_page_text = "Last";
		echo '<li class="bpn-last-page-link"><a href="'.get_pagenum_link($max_page).'" title="'.$last_page_text.'">'.$last_page_text.'</a></li>';
	}
	echo '</ol></nav>'.$after."";
}

/* Output Audio Player */

if ( !function_exists( 'creer_audio' ) ) {
    function creer_audio($postid, $width = 560, $height = 300) {
	
    	$mp3 = get_post_meta($postid, 'creer_audio_mp3', TRUE);
    	$ogg = get_post_meta($postid, 'creer_audio_ogg', TRUE);
    	$poster = get_post_meta($postid, 'creer_audio_poster_url', TRUE);
    	$height = get_post_meta($postid, 'creer_audio_height', TRUE);	
    ?>
    		<script type="text/javascript">
		
    			jQuery(document).ready(function($){
	
    				if( $().jPlayer ) {
    					$("#jquery-jplayer-audio-<?php echo $postid; ?>").jPlayer({
    						ready: function () {
    							$(this).jPlayer("setMedia", {
    							    <?php if($poster != '') : ?>
    							    poster: "<?php echo $poster; ?>",
    							    <?php endif; ?>
    							    <?php if($mp3 != '') : ?>
    								mp3: "<?php echo $mp3; ?>",
    								<?php endif; ?>
    								<?php if($ogg != '') : ?>
    								oga: "<?php echo $ogg; ?>",
    								<?php endif; ?>
    								end: ""
    							});
    						},
    						<?php if( !empty($poster) ) { ?>
    						size: {
            				    width: "<?php echo $width; ?>px",
            				    height: "<?php echo $height . 'px'; ?>"
            				},
            				<?php } ?>
    						swfPath: "<?php echo get_template_directory_uri(); ?>/includes/js",
    						cssSelectorAncestor: "#jp-audio-interface-<?php echo $postid; ?>",
    						supplied: "<?php if($ogg != '') : ?>oga,<?php endif; ?><?php if($mp3 != '') : ?>mp3<?php endif; ?>"
    					});
					
    				}
    			});
    		</script>
		
    	    <div id="jp-container-<?php echo $postid; ?>" class="jp-audio">
                <div class="jp-type-single">
                    <div id="jquery-jplayer-audio-<?php echo $postid; ?>" class="jp-jplayer" data-orig-width="<?php echo $width; ?>" data-orig-height="<?php echo $height; ?>"></div>
                    <div id="jp-audio-interface-<?php echo $postid; ?>" class="jp-interface">
                        <ul class="jp-controls">
                            <li><a href="#" class="jp-play" tabindex="1" title="play">play</a></li>
                            <li><a href="#" class="jp-pause" tabindex="1" title="pause">pause</a></li>
                            <li><a href="#" class="jp-mute" tabindex="1" title="mute">mute</a></li>
                            <li><a href="#" class="jp-unmute" tabindex="1" title="unmute">unmute</a></li>
                        </ul>
                        <div class="jp-progress">
                            <div class="jp-seek-bar">
                                <div class="jp-play-bar"></div>
                            </div>
                        </div>
                        <div class="jp-volume-bar">
                            <div class="jp-volume-bar-value"></div>
                        </div>
                    </div>
                </div>
            </div>
    	<?php 
    }
}

/* Random Cleanup Tools */

// remove the p from around imgs (http://css-tricks.com/snippets/wordpress/remove-paragraph-tags-from-around-images/)
function creer_filter_ptags_on_images($content){
   return preg_replace('/<p>\s*(<a .*>)?\s*(<img .* \/>)\s*(<\/a>)?\s*<\/p>/iU', '\1\2\3', $content);
}

// removes automatic paragrph tags from shortcodes
function remove_wpautop($content) {
    $content = do_shortcode( shortcode_unautop($content) ); 
    $content = preg_replace( '#^<\/p>|^<br \/>|<p>$#', '', $content );
    return $content;	
}

// This removes the annoying […] to a Read More link
function creer_excerpt_more($more) {
	global $post;
	return '...  <br /><a class="read-more" href="'. get_permalink($post->ID) . '" title="Read '.get_the_title($post->ID).'">Read More</a>';
}

?>