<?php

/* Crer Theme Options
-------------------------------------------------------------- */

/*
A unique identifier is defined to store the options in the database and reference them from the theme.
By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
If the identifier changes, it'll appear as if the options have been reset.
*/

function creerframework_option_name() {

	$themename = get_option( 'stylesheet' );
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$creerframework_settings = get_option( 'creerframework' );
	$creerframework_settings['id'] = $themename;
	update_option( 'creerframework', $creerframework_settings );
}

/*
Defines an array of options that will be used to generate the settings page and be saved in the database.
When creating the 'id' fields, make sure to use all lowercase and no spaces.

If you are making your theme translatable, you should replace 'options_framework_theme'
with the actual text domain for your theme.  Read more:
http://codex.wordpress.org/Function_Reference/load_theme_textdomain
*/

function creerframework_options() {

	$defined_stylesheets = array(
		"0" => "Default",
		get_stylesheet_directory_uri() . '/styles/blue.css' => "Dark",
		get_stylesheet_directory_uri() . '/styles/light.css' => "Light"
	);
	
	$alt_stylesheets = creer_stylesheets_get_file_list(
		get_stylesheet_directory() . '/styles/',
		'css', // $filetype
		get_stylesheet_directory_uri() . '/styles/'
	);

	// Test data
	$test_array = array(
		'one' => __('One', 'creerthemes'),
		'two' => __('Two', 'creerthemes'),
		'three' => __('Three', 'creerthemes'),
		'four' => __('Four', 'creerthemes'),
		'five' => __('Five', 'creerthemes')
	);

	// Multicheck Array
	$multicheck_array = array(
		'one' => __('French Toast', 'creerthemes'),
		'two' => __('Pancake', 'creerthemes'),
		'three' => __('Omelette', 'creerthemes'),
		'four' => __('Crepe', 'creerthemes'),
		'five' => __('Waffle', 'creerthemes')
	);

	// Multicheck Defaults
	$multicheck_defaults = array(
		'one' => '1',
		'five' => '1'
	);

	// Background Defaults
	$background_defaults = array(
		'color' => '',
		'image' => '',
		'repeat' => 'repeat',
		'position' => 'top center',
		'attachment'=>'scroll' );

	// Typography Defaults
	$typography_defaults = array(
		'size' => '15px',
		'face' => 'georgia',
		'style' => 'bold',
		'color' => '#bada55' );
		
	// Typography Options
	$typography_options = array(
		'sizes' => array( '6','12','14','16','20' ),
		'faces' => array( 'Helvetica Neue' => 'Helvetica Neue','Arial' => 'Arial' ),
		'styles' => array( 'normal' => 'Normal','bold' => 'Bold' ),
		'color' => false
	);
	
	$typography_mixed_fonts = array_merge( creer_typography_get_os_fonts() , creer_typography_get_google_fonts() );
		asort($typography_mixed_fonts);

	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
		$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Pull all tags into an array
	$options_tags = array();
	$options_tags_obj = get_tags();
	foreach ( $options_tags_obj as $tag ) {
		$options_tags[$tag->term_id] = $tag->name;
	}


	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}

	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/framework/images/';

	$options = array();
	
	/* General */
	$options[] = array(
		'name' => __('General', 'creerthemes'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Custom Logo', 'creerthemes'),
		'desc' => __('Upload a logo to your site.', 'creerthemes'),
		'id' => 'custom_logo',
		'type' => 'upload');

	$options[] = array(
		'name' => __('Plain Text Logo', 'creerthemes'),
		'desc' => __('Check this box if you prefer to use a text logo rather than an image.', 'creerthemes'),
		'id' => 'text_logo_showhidden',
		'std' => 'true',
		'type' => 'checkbox');
	
	$options[] = array(
		'name' => __('Custom Favicon', 'creerthemes'),
		'desc' => __('Upload a 16px x 16px Png/Gif image that will represent your website\'s favicon.', 'creerthemes'),
		'id' => 'custom_favicon',
		'type' => 'upload');
		
	$options[] = array(
		'name' => __('Contact Form Email', 'creerthemes'),
		'desc' => __('Enter the email address where you would like to receive emails from the contact form. Alternatively, leave blank to use admin email.', 'creerthemes'),
		'id' => 'contact_email',
		'type' => 'text');			

	$options[] = array(
		'name' => __('Tracking Code', 'creerthemes'),
		'desc' => __('Paste your Google Analytics (or other) tracking code here. This will be inserted before the closing body tag of your theme.', 'creerthemes'),
		'id' => 'tracking_code',
		'type' => 'textarea');
	
	$options[] = array(
		'name' => __('Footer Widgets', 'creerthemes'),
		'desc' => __('Check this box to deactivate the footer widget area', 'creerthemes'),
		'id' => 'foot_wid',
		'type' => 'checkbox');	

	$options[] = array(
		'name' => __('Enable Custom Footer Area', 'creerthemes'),
		'desc' => __('Activate to add custom text to the footer', 'creerthemes'),
		'id' => 'left_area_showhidden',
		'type' => 'checkbox');
		
	$options[] = array(
		'name' => __('Left Footer Content', 'creerthemes'),
		'desc' => __('Enter custom HTML and Text that will appear in the footer of your theme', 'creerthemes'),
		'id' => 'left_area_text_hidden',
		'std' => '',
		'class' => 'hidden',
		'type' => 'textarea');

	/* Styling */	
	$options[] = array(
		'name' => __('Styling', 'creerthemes'),
		'type' => 'heading');
		
	$options[] = array( "name" => "Theme Stylesheet",
		"desc" => 'Select your themes alternative color',
		"id" => "stylesheet",
		"type" => "select",
		"options" => $alt_stylesheets );
		
	$options[] = array(
		'name' =>  __('Background', 'creerthemes'),
		'desc' => __('Add a custom background color and image.', 'creerthemes'),
		'id' => 'custom_bg',
		'type' => 'background' );

	$options[] = array( 'name' => 'Body Typography',
		'desc' => 'Select the font and colour for the main body text. <em>Default cross-browser fonts are indicated with a (*)</em>',
		'id' => 'google_mixed',
		'std' => array('face' => '"Helvetica Neue", Helvetica, sans-serif'),
		'type' => 'typography',
		'options' => array(
			'faces' => $typography_mixed_fonts,
			'styles' => false )
		);
		
	$options[] = array( 'name' => 'Text Logo Typography',
		'desc' => 'Select the font and colour for the text logo (if used). <em>Default cross-browser fonts are indicated with a (*)</em>',
		'id' => 'google_mixed_2',
		'std' => array('face' => '"Helvetica Neue", Helvetica, sans-serif'),
		'type' => 'typography',
		'options' => array(
			'faces' => $typography_mixed_fonts,
			'styles' => false )
		);
	
	$options[] = array( 'name' => 'Header Titles Typography',
		'desc' => 'Select the font and colour for content & widget titles. <em>Default cross-browser fonts are indicated with a (*)</em>',
		'id' => 'google_mixed_1',
		'std' => array('face' => '"Helvetica Neue", Helvetica, sans-serif'),
		'type' => 'typography',
		'options' => array(
			'faces' => $typography_mixed_fonts,
			'styles' => false )
		);
	
	$options[] = array(
		'name' => __('Link Color', 'creerthemes'),
		'desc' => __('Select the color for links.', 'creerthemes'),
		'id' => 'link_color',
		'std' => '',
		'type' => 'color' );
		
	$options[] = array(
		'name' => __('Link Hover Color', 'creerthemes'),
		'desc' => __('Select the hover color for links.', 'creerthemes'),
		'id' => 'hover_color',
		'std' => '',
		'type' => 'color' );			
				
	$options[] = array(
		'name' => __('Custom CSS', 'creerthemes'),
		'desc' => __('Add your css here to overwrite the default css', 'creerthemes'),
		'id' => 'custom_css',
		'type' => 'textarea');		
		
	$options[] = array(
		'name' => __('Content', 'creerthemes'),
		'type' => 'heading');								

	$options[] = array(
		'name' => __('Post Meta', 'creerthemes'),
		'desc' => __('Check this box if you want to display post meta on pages', 'creerthemes'),
		'id' => 'post_meta',
		'type' => 'checkbox');	

	$options[] = array(
		'name' => __('Page Comments', 'creerthemes'),
		'desc' => __('Check this box if you want to display comments on pages', 'creerthemes'),
		'id' => 'page_com',
		'type' => 'checkbox');	

	$options[] = array(
		'name' => __('Related Posts', 'creerthemes'),
		'desc' => __('Check this box if you want to display related posts', 'creerthemes'),
		'id' => 'related_posts',
		'type' => 'checkbox');	

	$options[] = array(
		'name' => __('Author Box', 'creerthemes'),
		'desc' => __('Check this box if you want to display a post author box', 'creerthemes'),
		'id' => 'author_box',
		'type' => 'checkbox');
		
	$options[] = array(
		'name' => __('Enable Custom 404 Content', 'creerthemes'),
		'desc' => __('Activate to add custom text to the 404 error page', 'creerthemes'),
		'id' => '404_area_showhidden',
		'type' => 'checkbox');

	$options[] = array(
		'name' => __('404 Error Page Title', 'creerthemes'),
		'desc' => __('Enter your custom 404 error page title', 'creerthemes'),
		'id' => '404_title_text_hidden',
		'std' => '',
		'class' => 'hidden',
		'type' => 'text');
				
	$options[] = array(
		'name' => __('404 Error Page Content', 'creerthemes'),
		'desc' => __('Enter custom HTML and Text that will appear in 404 error page', 'creerthemes'),
		'id' => '404_area_text_hidden',
		'std' => '',
		'class' => 'hidden',
		'type' => 'textarea');

	$options[] = array(
		'name' => __('404 Page Search Form', 'creerthemes'),
		'desc' => __('Deactivate the search form that appears in the 404 error page', 'creerthemes'),
		'id' => '404_search',
		'type' => 'checkbox');			
		
	/* Crer Social */
	$options[] = array(
		'name' => __('Social', 'creerthemes'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Behance', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://www.behance.net\'>Behance</a> url <span><em>e.g. \'http://www.behance.net/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_behance',
		'type' => 'text');

	$options[] = array(
		'name' => __('Delicious', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://delicious.com/\'>Delicious</a> url <span><em>e.g. \'http://delicious.com/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_delicious',
		'type' => 'text');

	$options[] = array(
		'name' => __('deviantART', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://www.deviantart.com/\'>deviantART</a> url <span><em>e.g. \'http://username.deviantart.com\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_deviant',
		'type' => 'text');

	$options[] = array(
		'name' => __('Dopplr', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://www.dopplr.com/\'>Dopplr</a> url <span><em>e.g. \'http://www.dopplr.com/traveller/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_dopplr',
		'type' => 'text');

	$options[] = array(
		'name' => __('dribbble', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://dribbble.com/\'>dribbble</a> url <span><em>e.g. \'http://dribbble.com/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_dribbble',
		'type' => 'text');

	$options[] = array(
		'name' => __('Email', 'creerthemes'),
		'desc' => __('Enter your preferred email address <span><em>e.g. \'mailto:user@name.com\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_email',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Facebook', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://www.facebook.com/\'>Facebook</a> url <span><em>e.g. \'http://www.facebook.com/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_facebook',
		'type' => 'text');

	$options[] = array(
		'name' => __('Flickr', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://www.flickr.com/\'>Flickr</a> url <span><em>e.g. \'http://www.flickr.com/photos/username/\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_flickr',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Forrst', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://forrst.com/\'>Forrst</a> url <span><em>e.g. \'http://forrst.com/people/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_forrst',
		'type' => 'text');

	$options[] = array(
		'name' => __('Google+', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://plus.google.com/\'>Google+</a> url <span><em>e.g. \'http://plus.google.com/userID\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_googleplus',
		'type' => 'text');

	$options[] = array(
		'name' => __('Grooveshark', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://grooveshark.com/\'>Grooveshark</a> url <span><em>e.g. \'http://grooveshark.com/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_groove',
		'type' => 'text');					

	$options[] = array(
		'name' => __('Instagram', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://instagram.com/\'>Instagram</a> url <span><em>e.g. \'http://instagram.com/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_instagram',
		'type' => 'text');					

	$options[] = array(
		'name' => __('last.fm', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://www.lastfm.com/\'>last.fm</a> url <span><em>e.g. \'http://www.lastfm.com/user/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_lastfm',
		'type' => 'text');					

	$options[] = array(
		'name' => __('Linkedin', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://www.linkedin.com/\'>Linkedin</a> url <span><em>e.g. \'http://www.linkedin.com/profile/view?id=xxxxxxxx\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_linkedin',
		'type' => 'text');
	
	$options[] = array(
		'name' => __('myspace', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://www.myspace.com/\'>myspace</a> url <span><em>e.g. \'http://www.myspace.com/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_myspace',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Pinterest', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://pinterest.com/\'>Pinterest</a> url <span><em>e.g. \'http://pinterest.com/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_pinterest',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('posterous', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://posterous.com\'>posterous</a> url <span><em>e.g. \'http://username.posterous.com\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_posterous',
		'type' => 'text');

	$options[] = array(
		'name' => __('Custom RSS feed', 'creerthemes'),
		'desc' => __('Enter your custom RSS feed url <span><em>e.g. \'http://feeds.feedburner.com/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_rss',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Skype', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://skype.com/\'>Skype</a> username  <span><em>e.g. \'skype:username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_skype',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('SoundCloud', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://soundcloud.com/\'>SoundCloud</a> url <span><em>e.g. \'http://soundcloud.com/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_sound',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Spotify', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://www.spotify.com/\'>Spotify</a> url <span><em>e.g. \'http://open.spotify.com/user/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_spotify',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('StumbleUpon', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://www.stumbleupon.com/\'>StumbleUpon</a> url <span><em>e.g. \'http://www.stumbleupon.com/stumbler/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_stumble',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('tumblr', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://tumblr.com/\'>tumblr</a> url <span><em>e.g. \'http://username.tumblr.com\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_tumblr',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Twitter', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://twitter.com\'>Twitter</a> url <span><em>e.g. \'http://twitter.com/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_twitter',
		'type' => 'text');
	
	$options[] = array(
		'name' => __('Vimeo', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://vimeo.com/\'>Vimeo</a> url <span><em>e.g. \'http://vimeo.com/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_vimeo',
		'type' => 'text');
	
	$options[] = array(
		'name' => __('YouTube', 'creerthemes'),
		'desc' => __('Enter your <a href=\'http://www.youtube.com/\'>YouTube</a> url <span><em>e.g. \'http://www.youtube.com/user/username\'</em></span>', 'creerthemes'),
		'id' => 'creer_social_youtube',
		'type' => 'text');
		
	/* Contact */
	$options[] = array(
		'name' => __('Contact', 'creerthemes'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Enable Address', 'creerthemes'),
		'desc' => __('Activate to add your address and contact details to the contact page', 'creerthemes'),
		'id' => 'contact_area_showhidden',
		'type' => 'checkbox');

	$options[] = array(
		'name' => __('Location Name', 'creerthemes'),
		'desc' => __('Enter the location name <span><em>e.g. \'London Office\'</em></span>', 'creerthemes'),
		'id' => 'contact_title_text_hidden',
		'std' => '',
		'class' => 'hidden',
		'type' => 'text');

	$options[] = array(
		'name' => __('Location Address', 'creerthemes'),
		'desc' => __('Enter your address - HTML is allowed!', 'creerthemes'),
		'id' => 'contact_ad_text_hidden',
		'std' => '',
		'class' => 'hidden',
		'type' => 'textarea');	

	$options[] = array(
		'name' => __('Telephone Number', 'creerthemes'),
		'desc' => __('Enter your telephone or mobile number', 'creerthemes'),
		'id' => 'contact_tel_text_hidden',
		'std' => '',
		'class' => 'hidden',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Fax Number', 'creerthemes'),
		'desc' => __('Enter your face number', 'creerthemes'),
		'id' => 'contact_fax_text_hidden',
		'std' => '',
		'class' => 'hidden',
		'type' => 'text');

	$options[] = array(
		'name' => __('Email Address', 'creerthemes'),
		'desc' => __('Enter your preferred email address to be displayed under the address', 'creerthemes'),
		'id' => 'contact_email_text_hidden',
		'std' => '',
		'class' => 'hidden',
		'type' => 'text');
						
	return $options;
}

add_action('creerframework_custom_scripts', 'creerframework_custom_scripts');

function creerframework_custom_scripts() { ?>

<script type="text/javascript">
jQuery(document).ready(function($) {

	$('#text_logo_showhidden').click(function() {
  		$('#section-tagline_text_hidden').fadeToggle(400);
	});

	if ($('#text_logo_showhidden:checked').val() !== undefined) {
		$('#section-tagline_text_hidden').show();
	}

	$('#404_area_showhidden').click(function() {
  		$('#section-404_area_text_hidden').fadeToggle(400);
  		$('#section-404_title_text_hidden').fadeToggle(400);
	});

	if ($('#404_area_showhidden:checked').val() !== undefined) {
		$('#section-404_area_text_hidden').show();
		$('#section-404_title_text_hidden').show();
	}	
	
	$('#left_area_showhidden').click(function() {
  		$('#section-left_area_text_hidden').fadeToggle(400);
	});

	if ($('#left_area_showhidden:checked').val() !== undefined) {
		$('#section-left_area_text_hidden').show();
	}

	$('#contact_area_showhidden').click(function() {
  		$('#section-contact_title_text_hidden').fadeToggle(400);
  		$('#section-contact_ad_text_hidden').fadeToggle(400);
  		$('#section-contact_tel_text_hidden').fadeToggle(400);
  		$('#section-contact_fax_text_hidden').fadeToggle(400);
  		$('#section-contact_email_text_hidden').fadeToggle(400);
	});

	if ($('#contact_area_showhidden:checked').val() !== undefined) {
  		$('#section-contact_title_text_hidden').fadeToggle(400);
  		$('#section-contact_ad_text_hidden').fadeToggle(400);
  		$('#section-contact_tel_text_hidden').fadeToggle(400);
  		$('#section-contact_fax_text_hidden').fadeToggle(400);
  		$('#section-contact_email_text_hidden').fadeToggle(400);
  	}

});
</script>

<?php
}